# -*- coding: utf-8 -*-

translations = {
    # Days
    'days': {
        0: 'Bazar',
        1: 'Bazar ertəsi',
        2: 'Çərşənbə axşamı',
        3: 'Çərşənbə',
        4: 'Cümə axşamı',
        5: 'Cümə',
        6: 'Şənbə'
    },
    'days_abbrev': {
        0: 'Baz',
        1: 'BzE',
        2: 'ÇAx',
        3: 'Çər',
        4: 'CAx',
        5: 'Cüm',
        6: 'Şən'
    },

    # Months
    'months': {
        1: 'yanvar',
        2: 'fevral',
        3: 'mart',
        4: 'aprel',
        5: 'may',
        6: 'iyun',
        7: 'iyul',
        8: 'avqust',
        9: 'sentyabr',
        10: 'oktyabr',
        11: 'noyabr',
        12: 'dekabr',
    },
    'months_abbrev': {
        1: 'yan',
        2: 'fev',
        3: 'mar',
        4: 'apr',
        5: 'may',
        6: 'iyn',
        7: 'iyl',
        8: 'avq',
        9: 'sen',
        10: 'okt',
        11: 'noy',
        12: 'dek',
    },

    # Units of time
    'year': '{count} il',
    'month': '{count} ay',
    'week': '{count} həftə',
    'day': '{count} gün',
    'hour': '{count} saat',
    'minute': '{count} dəqiqə',
    'second': '{count} saniyə',

    # Relative time
    'ago': '{time} öncə',
    'from_now': '{time} sonra',
    'after': '{time} sonra',
    'before': '{time} öncə',

    # Date formats
    'date_formats': {
        'LTS': 'HH:mm:ss',
        'LT': 'HH:mm',
        'LLLL': 'dddd, D MMMM YYYY HH:mm',
        'LLL': 'D MMMM YYYY HH:mm',
        'LL': 'D MMMM YYYY',
        'L': 'DD.MM.YYYY',
    },
}
