# -*- coding: utf-8 -*-

translations = {
    # Days
    'days': {
        0: 'sunnudagur',
        1: 'mánadagur',
        2: 'týsdagur',
        3: 'mikudagur',
        4: 'hósdagur',
        5: 'fríggjadagur',
        6: 'leygardagur'
    },
    'days_abbrev': {
        0: 'sun',
        1: 'mán',
        2: 'týs',
        3: 'mik',
        4: 'hós',
        5: 'frí',
        6: 'ley'
    },

    # Months
    'months': {
        1: 'januar',
        2: 'februar',
        3: 'mars',
        4: 'apríl',
        5: 'mai',
        6: 'juni',
        7: 'juli',
        8: 'august',
        9: 'september',
        10: 'oktober',
        11: 'november',
        12: 'desember',
    },
    'months_abbrev': {
        1: 'jan',
        2: 'feb',
        3: 'mar',
        4: 'apr',
        5: 'mai',
        6: 'jun',
        7: 'jul',
        8: 'aug',
        9: 'sep',
        10: 'okt',
        11: 'nov',
        12: 'des',
    },

    # Units of time
    'year': ['{count} ár', '{count} ár'],
    'month': ['{count} mánaður', '{count} mánaðir'],
    'week': ['{count} vika', '{count} vikur'],
    'day': ['{count} dag', '{count} dagar'],
    'hour': ['{count} tími', '{count} tímar'],
    'minute': ['{count} minutt', '{count} minuttir'],
    'second': ['{count} sekund', '{count} sekundir'],

    # Relative time
    'ago': '{time} síðan',
    'from_now': 'um {time}',
    'after': '{time} aftaná',
    'before': '{time} áðrenn',

    # Ordinals
    'ordinal': '.',

    # Date formats
    'date_formats': {
        'LTS': 'HH:mm:ss',
        'LT': 'HH:mm',
        'LLLL': 'dddd D. MMMM, YYYY HH:mm',
        'LLL': 'D MMMM YYYY HH:mm',
        'LL': 'D MMMM YYYY',
        'L': 'DD/MM/YYYY',
    },
}
