# -*- coding: utf-8 -*-

translations = {
    # Days
    'days': {
        0: 'söndag',
        1: 'måndag',
        2: 'tisdag',
        3: 'onsdag',
        4: 'torsdag',
        5: 'fredag',
        6: 'lördag'
    },
    'days_abbrev': {
        0: 'sön',
        1: 'mån',
        2: 'tis',
        3: 'ons',
        4: 'tor',
        5: 'fre',
        6: 'lör'
    },

    # Months
    'months': {
        1: 'januari',
        2: 'februari',
        3: 'mars',
        4: 'april',
        5: 'maj',
        6: 'juni',
        7: 'juli',
        8: 'augusti',
        9: 'september',
        10: 'oktober',
        11: 'november',
        12: 'december',
    },
    'months_abbrev': {
        1: 'jan',
        2: 'feb',
        3: 'mar',
        4: 'apr',
        5: 'maj',
        6: 'jun',
        7: 'jul',
        8: 'aug',
        9: 'sep',
        10: 'okt',
        11: 'nov',
        12: 'dec',
    },

    # Units of time
    'year': ['{count} år', '{count} år'],
    'month': ['{count} månad', '{count} månader'],
    'week': ['{count} vecka', '{count} veckor'],
    'day': ['{count} dag', '{count} dagar'],
    'hour': ['{count} timme', '{count} timmar'],
    'minute': ['{count} minut', '{count} minuter'],
    'second': ['{count} sekund', '{count} sekunder'],

    # Relative time
    'ago': '{time} sedan',
    'from_now': 'om {time}',
    'after': '{time} efter',
    'before': '{time} före',

    # Date formats
    'date_formats': {
        'LTS': 'HH:mm:ss',
        'LT': 'HH:mm',
        'LLLL': 'dddd D MMMM YYYY [kl.] HH:mm',
        'LLL': 'D MMMM YYYY [kl.] HH:mm',
        'LL': 'D MMMM YYYY',
        'L': 'YYYY-MM-DD',
    },
}
