# -*- coding: utf-8 -*-

translations = {
    # Days
    'days': {
        0: 'კვირა',
        1: 'ორშაბათი',
        2: 'სამშაბათი',
        3: 'ოთხშაბათი',
        4: 'ხუთშაბათი',
        5: 'პარასკევი',
        6: 'შაბათი'
    },
    'days_abbrev': {
        0: 'კვი',
        1: 'ორშ',
        2: 'სამ',
        3: 'ოთხ',
        4: 'ხუთ',
        5: 'პარ',
        6: 'შაბ'
    },

    # Months
    'months': {
        1: 'იანვარი',
        2: 'თებერვალი',
        3: 'მარტი',
        4: 'აპრილი',
        5: 'მაისი',
        6: 'ივნისი',
        7: 'ივლისი',
        8: 'აგვისტო',
        9: 'სექტემბერი',
        10: 'ოქტომბერი',
        11: 'ნოემბერი',
        12: 'დეკემბერი'
    },
    'months_abbrev': {
        1: 'იან',
        2: 'თებ',
        3: 'მარ',
        4: 'აპრ',
        5: 'მაი',
        6: 'ივნ',
        7: 'ივლ',
        8: 'აგვ',
        9: 'სექ',
        10: 'ოქტ',
        11: 'ნოე',
        12: 'დეკ'
    },

    # Units of time
    'year': '{count} წლის',
    'month': '{count} თვის',
    'week': '{count} კვირის',
    'day': '{count} დღის',
    'hour': '{count} საათის',
    'minute': '{count} წუთის',
    'second': '{count} წამის',

    # Relative time
    'ago': '{time} უკან',
    'from_now': '{time} შემდეგ',
    'after': '{time} შემდეგ',
    'before': '{time} უკან',

    # Date formats
    'date_formats': {
        'LTS': 'h:mm:ss A',
        'LT': 'h:mm A',
        'LLLL': 'dddd, D MMMM YYYY h:mm A',
        'LLL': 'D MMMM YYYY h:mm A',
        'LL': 'D MMMM YYYY',
        'L': 'DD/MM/YYYY',
    },
}
