# -*- coding: utf-8 -*-

translations = {
    # Days
    'days': {
        0: 'igandea',
        1: 'astelehena',
        2: 'asteartea',
        3: 'asteazkena',
        4: 'osteguna',
        5: 'ostirala',
        6: 'larunbata'
    },
    'days_abbrev': {
        0: 'ig',
        1: 'al',
        2: 'ar',
        3: 'az',
        4: 'og',
        5: 'ol',
        6: 'lr'
    },

    # Months
    'months': {
        1: 'urtarrilak',
        2: 'otsailak',
        3: 'martxoak',
        4: 'apirilak',
        5: 'maiatzak',
        6: 'ekainak',
        7: 'uztailak',
        8: 'abuztuak',
        9: 'irailak',
        10: 'urriak',
        11: 'azaroak',
        12: 'abenduak',
    },
    'months_abbrev': {
        1: 'urt',
        2: 'ots',
        3: 'mar',
        4: 'api',
        5: 'mai',
        6: 'eka',
        7: 'uzt',
        8: 'abu',
        9: 'ira',
        10: 'urr',
        11: 'aza',
        12: 'abe',
    },

    # Units of time
    'year': ['Urte 1', '{count} urte'],
    'month': ['Hile 1', '{count} hile'],
    'week': ['Aste 1', '{count} aste'],
    'day': ['Egun 1', '{count} egun'],
    'hour': ['Ordu 1', '{count} ordu'],
    'minute': ['Minutu 1', '{count} minutu'],
    'second': ['Segundu 1', '{count} segundu'],

    # Relative time
    'ago': 'Orain dela {time}',
    'from_now': '{time} barru',
    'after': '{time} geroago',
    'before': '{time} lehenago',

    # Date formats
    'date_formats': {
        'LTS': 'HH:mm:ss',
        'LT': 'HH:mm',
        'LLLL': 'dddd, YYYY[ko] MMMM[ren] D[a] HH:mm',
        'LLL': 'YYYY[ko] MMMM[ren] D[a] HH:mm',
        'LL': 'YYYY[ko] MMMM[ren] D[a]',
        'L': 'YYYY-MM-DD',
    },
}
