# -*- coding: utf-8 -*-

translations = {
    # Days
    'days': {
        0: 'կիրակի',
        1: 'երկուշաբթի',
        2: 'երեքշաբթի',
        3: 'չորեքշաբթի',
        4: 'հինգշաբթի',
        5: 'ուրբաթ',
        6: 'շաբաթ'
    },
    'days_abbrev': {
        0: 'կրկ',
        1: 'երկ',
        2: 'երք',
        3: 'չրք',
        4: 'հնգ',
        5: 'ուրբ',
        6: 'շբթ'
    },

    # Months
    'months': {
        1: 'հունվար',
        2: 'փետրվար',
        3: 'մարտ',
        4: 'ապրիլ',
        5: 'մայիս',
        6: 'հունիս',
        7: 'հուլիս',
        8: 'օգոստոս',
        9: 'սեպտեմբեր',
        10: 'հոկտեմբեր',
        11: 'նոյեմբեր',
        12: 'դեկտեմբեր',
    },
    'months_abbrev': {
        1: 'հնվ',
        2: 'փտր',
        3: 'մրտ',
        4: 'ապր',
        5: 'մյս',
        6: 'հնս',
        7: 'հլս',
        8: 'օգս',
        9: 'սպտ',
        10: 'հկտ',
        11: 'նմբ',
        12: 'դկտ',
    },

    # Units of time
    'year': '{count} տարի',
    'month': '{count} ամիս',
    'week': '{count} շաբաթ',
    'day': '{count} օր',
    'hour': '{count} ժամ',
    'minute': '{count} րոպե',
    'second': '{count} վայրկյան',

    # Relative time
    'ago': '{time} առաջ',
    'from_now': '{time} հետո',
    'after': '{time} հետո',
    'before': '{time} առաջ',

    # Date formats
    'date_formats': {
        'LTS': 'HH:mm:ss',
        'LT': 'HH:mm',
        'LLLL': 'dddd, D MMMM YYYY թ., HH:mm',
        'LLL': 'D MMMM YYYY թ., HH:mm',
        'LL': 'D MMMM YYYY թ.',
        'L': 'DD.MM.YYYY',
    },
}
