# -*- coding: utf-8 -*-

translations = {
    # Days
    'days': {
        0: ' Недела',
        1: 'Понеделник',
        2: ' Вторник',
        3: ' Среда',
        4: ' Четврток',
        5: ' Петок',
        6: ' Сабота'
    },
    'days_abbrev': {
        0: ' Нед.',
        1: 'Пон.',
        2: ' Вт.',
        3: ' Сре.',
        4: ' Чет.',
        5: ' Пет.',
        6: ' Саб.'
    },

    # Months
    'months': {
        1: 'Јануари',
        2: 'Февруари',
        3: 'Март',
        4: 'Април',
        5: 'Мај',
        6: 'Јуни',
        7: 'Јули',
        8: 'Август',
        9: 'Септември',
        10: 'Октомври',
        11: 'Ноември',
        12: 'Декември',
    },
    'months_abbrev': {
        1: 'Јан.',
        2: ' Фев.',
        3: ' Мар.',
        4: ' Апр.',
        5: ' Мај',
        6: ' Јун.',
        7: ' Јул.',
        8: ' Авг.',
        9: ' Септ.',
        10: ' Окт.',
        11: ' Ноем.',
        12: ' Декем.',
    },

    # Units of time
    'year': ['{count} година', '{count} години'],
    'month': ['{count} месец', '{count} месеци'],
    'week': ['{count} седмица', '{count} седмици'],
    'day': ['{count} ден', '{count} дена'],
    'hour': ['{count} час', '{count} часа'],
    'minute': ['{count} минута', '{count} минути'],
    'second': ['{count} секунда', '{count} секунди'],

    # Relative time
    'ago': 'пред {time}',
    'from_now': '{time} од сега',
    'after': 'по {time}',
    'before': 'пред {time}',

    # Date formats
    'date_formats': {
        'LTS': 'H:mm:ss',
        'LT': 'H:mm',
        'LLLL': 'dddd, D MMMM YYYY H:mm',
        'LLL': 'D MMMM YYYY H:mm',
        'LL': 'D MMMM YYYY',
        'L': 'D.MM.YYYY',
    },
}
