# -*- coding: utf-8 -*-

translations = {
    # Days
    'days': {
        0: 'domenica',
        1: 'lunedì',
        2: 'martedì',
        3: 'mercoledì',
        4: 'giovedì',
        5: 'venerdì',
        6: 'sabato'
    },
    'days_abbrev': {
        0: 'dom',
        1: 'lun',
        2: 'mar',
        3: 'mer',
        4: 'gio',
        5: 'ven',
        6: 'sab'
    },

    # Months
    'months': {
        1: 'gennaio',
        2: 'febbraio',
        3: 'marzo',
        4: 'aprile',
        5: 'maggio',
        6: 'giugno',
        7: 'luglio',
        8: 'agosto',
        9: 'settembre',
        10: 'ottobre',
        11: 'novembre',
        12: 'dicembre',
    },
    'months_abbrev': {
        1: 'gen',
        2: 'feb',
        3: 'mar',
        4: 'apr',
        5: 'mag',
        6: 'giu',
        7: 'lug',
        8: 'ago',
        9: 'set',
        10: 'ott',
        11: 'nov',
        12: 'dic',
    },

    # Units of time
    'year': ['{count} anno', '{count} anni'],
    'month': ['{count} mese', '{count} mesi'],
    'week': ['{count} settimana', '{count} settimane'],
    'day': ['{count} giorno', '{count} giorni'],
    'hour': ['{count} ora', '{count} ore'],
    'minute': ['{count} minuto', '{count} minuti'],
    'second': ['{count} secondo', '{count} secondi'],

    # Relative time
    'ago': '{time} fa',
    'from_now': '{time} da adesso',
    'after': '{time} dopo',
    'before': '{time} prima',

    # Date formats
    'date_formats': {
        'LTS': 'HH:mm:ss',
        'LT': 'HH:mm',
        'LLLL': 'dddd, D MMMM YYYY HH:mm',
        'LLL': 'D MMMM YYYY HH:mm',
        'LL': 'D MMMM YYYY',
        'L': 'DD/MM/YYYY',
    },
}
