# -*- coding: utf-8 -*-

from .af import translations as af_translations
from .ar import translations as ar_translations
from .az import translations as az_translations
from .bg import translations as bg_translations
from .bn import translations as bn_translations
from .ca import translations as ca_translations
from .cs import translations as cs_translations
from .da import translations as da_translations
from .de import translations as de_translations
from .el import translations as el_translations
from .en import translations as en_translations
from .eo import translations as eo_translations
from .es import translations as es_translations
from .et import translations as et_translations
from .eu import translations as eu_translations
from .fa import translations as fa_translations
from .fi import translations as fi_translations
from .fo import translations as fo_translations
from .fr import translations as fr_translations
from .gl import translations as gl_translations
from .he import translations as he_translations
from .hr import translations as hr_translations
from .hu import translations as hu_translations
from .hy import translations as hy_translations
from .id import translations as id_translations
from .it import translations as it_translations
from .ja import translations as ja_translations
from .ka import translations as ka_translations
from .ko import translations as ko_translations
from .lt import translations as lt_translations
from .lv import translations as lv_translations
from .mk import translations as mk_translations
from .ms import translations as ms_translations
from .nl import translations as nl_translations
from .nn import translations as nn_translations
from .pl import translations as pl_translations
from .pt_br import translations as pt_br_translations
from .ro import translations as ro_translations
from .ru import translations as ru_translations
from .sk import translations as sk_translations
from .sl import translations as sl_translations
from .sq import translations as sq_translations
from .sr import translations as sr_translations
from .sv import translations as sv_translations
from .th import translations as th_translations
from .tr import translations as tr_translations
from .uk import translations as uk_translations
from .uz import translations as uz_translations
from .vi import translations as vi_translations
from .zh import translations as zh_translations
from .zh_tw import translations as zh_tw_translations


TRANSLATIONS = {
    "af": af_translations,
    "ar": ar_translations,
    "az": az_translations,
    "bg": bg_translations,
    "bn": bn_translations,
    "ca": ca_translations,
    "cs": cs_translations,
    "da": da_translations,
    "de": de_translations,
    "el": el_translations,
    "en": en_translations,
    "eo": eo_translations,
    "es": es_translations,
    "et": et_translations,
    "eu": eu_translations,
    "fa": fa_translations,
    "fi": fi_translations,
    "fo": fo_translations,
    "fr": fr_translations,
    "gl": gl_translations,
    "he": he_translations,
    "hr": hr_translations,
    "hu": hu_translations,
    "hy": hy_translations,
    "id": id_translations,
    "it": it_translations,
    "ja": ja_translations,
    "ka": ka_translations,
    "ko": ko_translations,
    "lt": lt_translations,
    "lv": lv_translations,
    "mk": mk_translations,
    "ms": ms_translations,
    "nl": nl_translations,
    "nn": nn_translations,
    "pl": pl_translations,
    "pt_br": pt_br_translations,
    "ro": ro_translations,
    "ru": ru_translations,
    "sk": sk_translations,
    "sl": sl_translations,
    "sq": sq_translations,
    "sr": sr_translations,
    "sv": sv_translations,
    "th": th_translations,
    "tr": tr_translations,
    "uk": uk_translations,
    "uz": uz_translations,
    "vi": vi_translations,
    "zh": zh_translations,
    "zh_tw": zh_tw_translations,
}
