# -*- coding: utf-8 -*-

translations = {
    # Days
    'days': {
        0: 'неделя',
        1: 'понеделник',
        2: 'вторник',
        3: 'сряда',
        4: 'четвъртък',
        5: 'петък',
        6: 'събота'
    },
    'days_abbrev': {
        0: 'нед',
        1: 'пон',
        2: 'вт',
        3: 'ср',
        4: 'четв',
        5: 'пет',
        6: 'съб'
    },

    # Months
    'months': {
        1: 'януари',
        2: 'февруари',
        3: 'март',
        4: 'април',
        5: 'май',
        6: 'юни',
        7: 'юли',
        8: 'август',
        9: 'септември',
        10: 'октомври',
        11: 'ноември',
        12: 'декември',
    },
    'months_abbrev': {
        1: 'ян',
        2: 'февр',
        3: 'март',
        4: 'апр',
        5: 'май',
        6: 'юни',
        7: 'юли',
        8: 'авг',
        9: 'септ',
        10: 'окт',
        11: 'ноем',
        12: 'дек',
    },

    # Units of time
    'year': ['{count} година', '{count} години'],
    'month': ['{count} месец', '{count} месеца'],
    'week': ['{count} седмица', '{count} седмици'],
    'day': ['{count} ден', '{count} дни'],
    'hour': ['{count} час', '{count} часа'],
    'minute': ['{count} минута', '{count} минути'],
    'second': ['{count} секунда', '{count} секунди'],

    # Relative time
    'ago': 'преди {time}',
    'from_now': '{time} от сега',
    'after': 'след {time}',
    'before': 'преди {time}',

    # Date formats
    'date_formats': {
        'LTS': 'H:mm:ss',
        'LT': 'H:mm',
        'LLLL': 'dddd, D MMMM YYYY H:mm',
        'LLL': 'D MMMM YYYY H:mm',
        'LL': 'D MMMM YYYY',
        'L': 'D.MM.YYYY',
    },
}
