# -*- coding: utf-8 -*-

translations = {
    # Days
    'days': {
        0: 'nedelja',
        1: 'ponedeljak',
        2: 'utorak',
        3: 'sreda',
        4: 'četvrtak',
        5: 'petak',
        6: 'subota'
    },
    'days_abbrev': {
        0: 'ned.',
        1: 'pon.',
        2: 'uto.',
        3: 'sre.',
        4: 'čet.',
        5: 'pet.',
        6: 'sub.'
    },

    # Months
    'months': {
        1: 'januar',
        2: 'februar',
        3: 'mart',
        4: 'april',
        5: 'maj',
        6: 'jun',
        7: 'jul',
        8: 'avgust',
        9: 'septembar',
        10: 'oktobar',
        11: 'novembar',
        12: 'decembar'
    },
    'months_abbrev': {
        1: 'jan.',
        2: 'feb.',
        3: 'mar.',
        4: 'apr.',
        5: 'maj',
        6: 'jun',
        7: 'jul',
        8: 'avg.',
        9: 'sep.',
        10: 'okt.',
        11: 'nov.',
        12: 'dec.'
    },

    # Units of time
    'year': ['{count} godina', '{count} godine', '{count} godina'],
    'month': ['{count} mesec', '{count} meseca', '{count} meseci'],
    'week': ['{count} nedelja', '{count} nedelje', '{count} nedelja'],
    'day': ['{count} dan', '{count} dana', '{count} dana'],
    'hour': ['{count} sat', '{count} sata', '{count} sati'],
    'minute': ['{count} minut', '{count} minuta ', '{count} minuta'],
    'second': ['{count} sekund', '{count} sekunde', '{count} sekunde'],

    # Relative time
    'ago': 'pre {time}',
    'from_now': '{time} od sada',
    'after': 'nakon {time}',
    'before': 'pre {time}',

    # Date formats
    'date_formats': {
        'LTS': 'H:mm:ss',
        'LT': 'H:mm',
        'LLLL': 'dddd, D. MMMM YYYY H:mm',
        'LLL': 'D. MMMM YYYY H:mm',
        'LL': 'D. MMMM YYYY',
        'L': 'DD. MM. YYYY',
    },
}
